/*
 * This file is a part of KleanSweep.
 *
 * Copyright (C) 2005 Pawel Stolowski <pawel.stolowski@wp.pl>
 *
 * KleanSweep is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "configdlg.h"
#include "dirlistwidget.h"
#include <qlayout.h>
#include <klocale.h>
#include <kleansweepcfg.h>

KleanSweepConfigDialog::KleanSweepConfigDialog(QWidget *parent): KDialogBase(KDialogBase::Tabbed, i18n("KleanSweep settings"), KDialogBase::Apply|KDialogBase::Cancel, KDialogBase::NoDefault, parent, 0, true)
{
	setMinimumSize(500, 380);
	setupGeneralPage();
	setupOrphansPage();
}

KleanSweepConfigDialog::~KleanSweepConfigDialog()
{
}

void KleanSweepConfigDialog::setupGeneralPage()
{
	QFrame *page = addPage(i18n("General"));
	QVBoxLayout *lay = new QVBoxLayout(page, 0, KDialog::spacingHint());
	globalexcl = new DirListWidget(i18n("Directories to exclude (all scans)"), page);
	globalexcl->insertStringList(KleanSweepConfig::instance().globalExcludePaths());
	lay->addWidget(globalexcl);
}

void KleanSweepConfigDialog::setupOrphansPage()
{
	KleanSweepConfig *cfg = &KleanSweepConfig::instance();

	QFrame *page = addPage(i18n("Orphaned files searching"));
	QVBoxLayout *lay = new QVBoxLayout(page, 0, KDialog::spacingHint());
	orphincl = new DirListWidget(i18n("Directories to include"), page);
	orphincl->insertStringList(cfg->orphansIncludePaths());
	orphexcl = new DirListWidget(i18n("Directories to exclude"), page);
	orphexcl->insertStringList(cfg->orphansExcludePaths());
	lay->addWidget(orphincl);
	lay->addWidget(orphexcl);
}

void KleanSweepConfigDialog::slotApply()
{
	KleanSweepConfig *cfg = &KleanSweepConfig::instance();
	cfg->globalExcludePaths(globalexcl->getAllPaths());
	cfg->orphansExcludePaths(orphexcl->getAllPaths());
	cfg->orphansIncludePaths(orphincl->getAllPaths());
	QDialog::accept();
}

#include "configdlg.moc"
